@@ -29,7 +29,6 @@
 #include <NetworkManager.h>
 #endif /* HAVE_NETWORK_MANAGER */
 
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gsd-sharing-manager.h"
 #include "gsd-sharing-enums.h"
@@ -60,6 +59,10 @@ struct GsdSharingManagerPrivate
         GsdSharingStatus         sharing_status;
 };
 
+#define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
+#define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
+#define GSD_DBUS_BASE_INTERFACE "org.gnome.SettingsDaemon"
+
 #define GSD_SHARING_DBUS_NAME GSD_DBUS_NAME ".Sharing"
 #define GSD_SHARING_DBUS_PATH GSD_DBUS_PATH "/Sharing"
 
@@ -749,8 +752,11 @@ gsd_sharing_manager_stop (GsdSharingManager *manager)
 {
         g_debug ("Stopping sharing manager");
 
-        manager->priv->sharing_status = GSD_SHARING_STATUS_OFFLINE;
-        gsd_sharing_manager_sync_services (manager);
+        if (manager->priv->sharing_status == GSD_SHARING_STATUS_AVAILABLE &&
+            manager->priv->connection != NULL) {
+                manager->priv->sharing_status = GSD_SHARING_STATUS_OFFLINE;
+                gsd_sharing_manager_sync_services (manager);
+        }
 
         if (manager->priv->cancellable) {
                 g_cancellable_cancel (manager->priv->cancellable);
