@@ -36,7 +36,7 @@
 #include <gio/gio.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#if 0
+#ifdef HAVE_UPOWER
 #include <libupower-glib/upower.h>
 #endif
 
@@ -48,7 +48,6 @@
 
 #include "gsd-enums.h"
 #include "gsd-input-helper.h"
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gnome-settings-bus.h"
 #include "gsd-device-mapper.h"
@@ -67,6 +66,10 @@
 /* name of the icon files (gsd-xrandr.svg, etc.) */
 #define GSD_XRANDR_ICON_NAME "gsd-xrandr"
 
+#define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
+#define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
+#define GSD_DBUS_BASE_INTERFACE "org.gnome.SettingsDaemon"
+
 #define GSD_XRANDR_DBUS_NAME GSD_DBUS_NAME ".XRANDR"
 #define GSD_XRANDR_DBUS_PATH GSD_DBUS_PATH "/XRANDR"
 
@@ -94,7 +97,7 @@ struct GsdXrandrManagerPrivate {
         GnomeRRScreen *rw_screen;
         gboolean running;
 
-#if 0
+#ifdef HAVE_UPOWER
         UpClient *upower_client;
 #endif
 
@@ -461,7 +464,7 @@ config_is_all_off (GnomeRRConfig *config)
 static gboolean
 laptop_lid_is_closed (GsdXrandrManager *manager)
 {
-#if 0
+#ifdef HAVE_UPOWER
         return up_client_get_lid_is_closed (manager->priv->upower_client);
 #else
         return FALSE;
@@ -1233,7 +1236,7 @@ on_rr_screen_acquired (GObject      *object,
                 return;
         }
 
-#if 0
+#ifdef HAVE_UPOWER
         manager->priv->upower_client = up_client_new ();
 #endif
 
@@ -1290,7 +1293,7 @@ gsd_xrandr_manager_stop (GsdXrandrManager *manager)
                 manager->priv->rw_screen = NULL;
         }
 
-#if 0
+#ifdef HAVE_UPOWER
         if (manager->priv->upower_client != NULL) {
                 g_signal_handlers_disconnect_by_data (manager->priv->upower_client, manager);
                 g_object_unref (manager->priv->upower_client);
@@ -1298,8 +1301,10 @@ gsd_xrandr_manager_stop (GsdXrandrManager *manager)
         }
 #endif
 
-        if (manager->priv->name_id != 0)
+        if (manager->priv->name_id != 0) {
                 g_bus_unown_name (manager->priv->name_id);
+                manager->priv->name_id = 0;
+        }
 
         if (manager->priv->introspection_data) {
                 g_dbus_node_info_unref (manager->priv->introspection_data);
